@@ -1,4 +1,7 @@
+## Edited by TDLogger
+from example.logger_instance import logger
 
+@logger
 class Fib:
 
     @staticmethod
